"""
This package contains the modules related to this library's use of
persistent storage.

@sort: interface, filestore, sqlstore, memstore
"""
